<?php

/*
Plugin Name: Calculadora Fitness DR
Description: Procure na barra lateral do WordPress pelo item Calc Fitness, lá você vai encontrar as calculadoras e as instruções de uso. A utilização deste plugin é de total responsabilidade do usuário. O desenvolvedor não se responsabiliza por qualquer dano, perda de dados ou problemas que possam ocorrer em decorrência do uso ou instalação deste plugin. Recomenda-se realizar backups regulares antes de qualquer instalação e atualização. Ao utilizar este plugin, o usuário concorda com esses termos.
Version: 1.0
Author: Prof. Durval de Deus
Author URI: https://ambr.com.br/sobre-os-autores/
*/

// Prevenir acesso direto ao arquivo
if (!defined('ABSPATH')) {
    exit;
}

function fcp_add_admin_menu() {
    add_menu_page(
        'Calc Fitness', 
        'Calc Fitness', 
        'manage_options',   
        'fcp_admin_page',   
        'fcp_render_admin_page', 
        'dashicons-admin-customizer', 
        110
    );
}
add_action( 'admin_menu', 'fcp_add_admin_menu' );


function fcp_render_admin_page() {
    ?>
    <div class="container" style="max-width: 800px; margin: 0 auto; padding: 20px; background-color: #fff; box-shadow: 0px 4px 8px rgba(0, 0, 0, 0.1); border-radius: 10px;">
        <h1>Shortcodes das Calculadoras</h1>
		<h2>INSTRUÇÕES</h2>
        <h3>Ao clicar no botão ao lado do nome da calculadora você irá copiar o shortcode da calculadora escolhida.</h3>
        <h3>Cole este shortcode em qualquer parte da área de edição do seu post para que ali seja inserida a calculadora desejada.</h3>
        <p>O uso deste plugin vai gera um link no final de sua página. Se você quer continuar usando o plugin mas não quer mais o link entre em contato por esta email: avaliamelhores@gmail.com</p>
		<p>Este plugin é registrado a cópia, distribuição ou modificação do código é proibida.. </p>
        <hr style="border: 1px solid black; width: 50%; margin-bottom: 10px;">

        <ul style="list-style-type: none; padding: 0;">
            <?php
            $calculadoras = array(
                'Calculadora de VO2 Máx' => array(
                    'shortcode' => '[calc_vo2_max_dr]',
                    'descricao' => 'Calcula o volume máximo de oxigênio que seu corpo pode utilizar durante o exercício.'
                ),
                'Calculadora de Reserva de VO2' => array(
                    'shortcode' => '[calc_reserva_vo2_dr]',
                    'descricao' => 'Determina a reserva de oxigênio do corpo para medir a intensidade do exercício.'
                ),
                'Calculadora de Macronutrientes' => array(
                    'shortcode' => '[calc_macronutrientes_dr]',
                    'descricao' => 'Calcula a quantidade ideal de macronutrientes (proteínas, carboidratos e gorduras) para sua dieta.'
                ),
                'Calculadora de volume de treino' => array(
                    'shortcode' => '[calc_volume_treino_dr]',
                    'descricao' => 'Avalia o volume de treino baseado na quantidade de repetições e séries realizadas.'
                ),
                'Calculadora de Força Máxima (1RM)' => array(
                    'shortcode' => '[calc_forca_maxima_dr]',
                    'descricao' => 'Estima a carga máxima que você consegue levantar em uma única repetição.'
                ),
                'Calculadora de Consumo Diário de Água' => array(
                    'shortcode' => '[calc_consumo_agua_dr]',
                    'descricao' => 'Calcula a quantidade ideal de água que você deve consumir diariamente com base no seu peso.'
                ),
                'Calculadora de Frequência Cardíaca Máxima' => array(
                    'shortcode' => '[calc_freq_cardiaca_maxima_dr]',
                    'descricao' => 'Determina sua frequência cardíaca máxima com base na idade para ajudar a monitorar a intensidade do exercício.'
                ),
                'Calculadora de Índice de Massa Corporal (IMC)' => array(
                    'shortcode' => '[calc_imc_dr]',
                    'descricao' => 'Calcula o seu Índice de Massa Corporal (IMC) para classificar seu peso em relação à altura.'
                ),
                'Calculadora de Percentual de Gordura Corporal' => array(
                    'shortcode' => '[calc_percentual_gordura_dr]',
                    'descricao' => 'Estima o percentual de gordura corporal baseado em medições corporais.'
                ),
                'Calculadora de Metas de Perda ou Ganho de Peso' => array(
                    'shortcode' => '[calc_metas_peso_dr]',
                    'descricao' => 'Ajuda a definir metas para perda ou ganho de peso com base no consumo calórico.'
                ),
            );

            foreach ( $calculadoras as $nome => $dados ) {
                echo '<li style="margin-bottom: 20px; background-color: #f9f9f9; padding: 20px; border: 1px solid #ddd; border-radius: 5px;">';
                echo '<strong>' . esc_html( $nome ) . '</strong>';
                echo ' <button class="button fcp-copy-btn" data-clipboard-text="' . esc_attr( $dados['shortcode'] ) . '" style="margin-left: 10px;">Copiar shortcode</button>';
                echo '<p>' . esc_html( $dados['descricao'] ) . '</p>';
                //echo '<hr style="border: 1px solid black; width: 100%; margin-bottom: 20px;">';  // Adiciona a linha divisória
                echo '</li>';
            }
            ?>
        </ul>
    </div>
    <?php
}

function fcp_enqueue_admin_scripts($hook) {
    if ( 'toplevel_page_fcp_admin_page' !== $hook ) {
        return;
    }
    wp_enqueue_script( 'clipboard-js', 'https://cdnjs.cloudflare.com/ajax/libs/clipboard.js/2.0.6/clipboard.min.js', array(), '2.0.6', true );
    wp_add_inline_script( 'clipboard-js', "
        document.addEventListener('DOMContentLoaded', function() {
            var clipboard = new ClipboardJS('.fcp-copy-btn');
            clipboard.on('success', function(e) {
                alert('Shortcode copiado para o clipboard: ' + e.text);
                e.clearSelection();
            });
            clipboard.on('error', function(e) {
                alert('Falha ao copiar!');
            });
        });
    ");
}
add_action( 'admin_enqueue_scripts', 'fcp_enqueue_admin_scripts' );

function calculadora_fitness_dr_enqueue_scripts() {
    wp_enqueue_style('calculadora-fitness-dr-style', plugins_url('/css/style.css', __FILE__));
    wp_enqueue_script('calculadora-fitness-dr-script', plugins_url('/js/scripts.js', __FILE__), array('jquery'), null, true);
}
add_action('wp_enqueue_scripts', 'calculadora_fitness_dr_enqueue_scripts');

function calculator_template_start($title) {
    ob_start();
    ?>
    <div class="calculator-wrapper" style="display: flex; justify-content: center; align-items: center; min-height: 50vh; margin: 20px 0;">
        <div class="calculator-container" style="max-width: 600px; width: 100%; text-align: center; padding: 20px; border: 1px solid #ddd; border-radius: 10px; box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1); background-color: #f9f9f9;">
            <h2><?php echo $title; ?></h2>
    <?php
}

function calculator_template_end() {
    ?>
        </div>
    </div>
    <?php
    return ob_get_clean();
}

function calculator_volume_treino() {
    echo calculator_template_start('Otimize seu Desempenho: Calcule o Volume Ideal de Treino Ajustado pela Idade');
    ?>
    <form id="volumeTreinoForm">
        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required><br><br>

        <label for="sets">Número de Séries:</label>
        <input type="number" id="sets" name="sets" required><br><br>

        <label for="reps">Número de Repetições por Série:</label>
        <input type="number" id="reps" name="reps" required><br><br>

        <label for="carga">Carga Utilizada (kg):</label>
        <input type="number" id="carga" name="carga" required><br><br>

        <button type="submit">Calcular Volume Ideal</button>
    </form>
    
    <div id="resultado"></div>

    <script>
    document.getElementById("volumeTreinoForm").addEventListener("submit", function(event) {
        event.preventDefault();
        
        var idade = document.getElementById("idade").value;
        var sets = document.getElementById("sets").value;
        var reps = document.getElementById("reps").value;
        var carga = document.getElementById("carga").value;

        var volumeBasico = sets * reps * carga;

        var fatorIdade = (100 - idade) / 100;

        var volumeIdeal = volumeBasico * fatorIdade;

        document.getElementById("resultado").innerHTML = "<h3>Volume Básico de Treino: " + volumeBasico.toFixed(2) + " kg</h3>" +
                                                         "<h3>Fator de Ajuste pela Idade: " + fatorIdade.toFixed(2) + "</h3>" +
                                                         "<h3>Volume Ideal de Treino: " + volumeIdeal.toFixed(2) + " kg</h3>";
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_volume_treino_dr', 'calculator_volume_treino');

function calculator_forca_maxima() {
    echo calculator_template_start('Calcule sua Força Máxima (1RM)');
    ?>
    <form id="forcaMaximaForm">
        <label for="carga">Carga levantada (kg):</label>
        <input type="number" id="carga" name="carga" required><br><br>

        <label for="reps">Número de repetições:</label>
        <input type="number" id="reps" name="reps" required><br><br>

        <button type="submit">Calcular Força Máxima</button>
    </form>
    
    <div id="resultado"></div>

    <script>
    document.getElementById("forcaMaximaForm").addEventListener("submit", function(event) {
        event.preventDefault();
        
        var carga = document.getElementById("carga").value;
        var reps = document.getElementById("reps").value;

        var forcaMaxima = carga * (1 + reps / 30);

        document.getElementById("resultado").innerHTML = "<h3>Força Máxima (1RM) Estimada: " + forcaMaxima.toFixed(2) + " kg</h3>";
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_forca_maxima_dr', 'calculator_forca_maxima');

function calculator_vo2r() {
    echo calculator_template_start('Calculadora de Reserva de VO2 (VO2R)');
    ?>
    <form id="vo2rForm">
        <label for="vo2max">VO2 Máximo (ml/kg/min):</label>
        <input type="number" id="vo2max" name="vo2max" step="0.1" required><br><br>

        <label for="vo2repouso">VO2 de Repouso (ml/kg/min):</label>
        <input type="number" id="vo2repouso" name="vo2repouso" value="3.5" step="0.1"><br><br>

        <label for="intensidade">Intensidade do Exercício (%):</label>
        <input type="number" id="intensidade" name="intensidade" step="0.1" required><br><br>

        <label for="idade">Idade (opcional, anos):</label>
        <input type="number" id="idade" name="idade"><br><br>

        <button type="submit">Calcular VO2R</button>
    </form>
    
    <div id="resultado"></div>

    <script>
    document.getElementById("vo2rForm").addEventListener("submit", function(event) {
        event.preventDefault();
        
        var vo2max = parseFloat(document.getElementById("vo2max").value);
        var vo2repouso = parseFloat(document.getElementById("vo2repouso").value);
        var intensidade = parseFloat(document.getElementById("intensidade").value);
        
        var vo2r = vo2max - vo2repouso;
        var vo2intensidade = vo2repouso + (vo2r * (intensidade / 100));

        var categoria;
        if (intensidade < 40) {
            categoria = "leve";
        } else if (intensidade < 70) {
            categoria = "moderado";
        } else {
            categoria = "vigoroso";
        }

        document.getElementById("resultado").innerHTML = "<h3>Reserva de VO2 (VO2R): " + vo2intensidade.toFixed(2) + " ml/kg/min</h3><h3>Categoria do Treinamento: " + categoria + "</h3>";
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_reserva_vo2_dr', 'calculator_vo2r');

function calculator_metas_peso() {
    echo calculator_template_start('Transforme seu Corpo: Calcule suas Metas de Perda ou Ganho de Peso');
    ?>
    <form id="metasPesoForm">
        <label for="pesoAtual">Peso Atual (kg):</label>
        <input type="number" id="pesoAtual" name="pesoAtual" required><br><br>

        <label for="pesoDesejado">Peso Desejado (kg):</label>
        <input type="number" id="pesoDesejado" name="pesoDesejado" required><br><br>

        <label for="dias">Tempo para a meta (dias):</label>
        <input type="number" id="dias" name="dias" required><br><br>

        <button type="submit">Calcular Meta de Peso</button>
    </form>
    
    <div id="resultado"></div>

    <script>
    document.getElementById("metasPesoForm").addEventListener("submit", function(event) {
        event.preventDefault();
        var pesoAtual = document.getElementById("pesoAtual").value;
        var pesoDesejado = document.getElementById("pesoDesejado").value;
        var dias = document.getElementById("dias").value;
        var diferencaPeso = pesoAtual - pesoDesejado;
        var metaPorDia = diferencaPeso / dias;
        document.getElementById("resultado").innerHTML = "<h3>Você precisa perder/ganhar " + metaPorDia.toFixed(2) + " kg por dia para atingir sua meta.</h3>";
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_metas_peso_dr', 'calculator_metas_peso');

function calculator_consumo_agua() {
    echo calculator_template_start('Calculadora de Consumo Diário de Água');
    ?>
    <form id="aguaForm">
        <label for="peso">Peso Corporal (kg):</label>
        <input type="number" id="peso" name="peso" step="0.1" required><br><br>

        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required><br><br>

        <label for="sexo">Sexo:</label>
        <select id="sexo" name="sexo" required>
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select><br><br>

        <label for="nivelAtividade">Nível de Atividade Física:</label>
        <select id="nivelAtividade" name="nivelAtividade" required>
            <option value="sedentario">Sedentário</option>
            <option value="levementeAtivo">Levemente ativo (+10%)</option>
            <option value="moderadamenteAtivo">Moderadamente ativo (+20%)</option>
            <option value="altamenteAtivo">Altamente ativo (+30%)</option>
            <option value="extremamenteAtivo">Extremamente ativo (+40%)</option>
        </select><br><br>

        <label for="clima">Clima ou Ambiente:</label>
        <select id="clima" name="clima">
            <option value="temperado">Temperado</option>
            <option value="quente">Quente (+10%)</option>
            <option value="seco">Seco (+10%)</option>
            <option value="frio">Frio</option>
        </select><br><br>

        <label for="estadoFisiologico">Estado Fisiológico Especial:</label>
        <select id="estadoFisiologico" name="estadoFisiologico">
            <option value="naoAplicavel">Não aplicável</option>
            <option value="gravidez">Gravidez (+300 ml)</option>
            <option value="lactacao">Lactação (+700 ml)</option>
        </select><br><br>

        <button type="submit">Calcular</button>
    </form>
    
    <div id="resultado"></div>

    <script>
    document.getElementById("aguaForm").addEventListener("submit", function(event) {
        event.preventDefault();

        var peso = parseFloat(document.getElementById("peso").value);
        var nivelAtividade = document.getElementById("nivelAtividade").value;
        var clima = document.getElementById("clima").value;
        var estadoFisiologico = document.getElementById("estadoFisiologico").value;

        var consumoBasico = (peso * 35) / 1000; // Consumo básico em litros

        var fatorAtividade = 1;
        switch (nivelAtividade) {
            case "levementeAtivo":
                fatorAtividade = 1.10;
                break;
            case "moderadamenteAtivo":
                fatorAtividade = 1.20;
                break;
            case "altamenteAtivo":
                fatorAtividade = 1.30;
                break;
            case "extremamenteAtivo":
                fatorAtividade = 1.40;
                break;
        }

        var fatorClima = 1;
        if (clima === "quente" || clima === "seco") {
            fatorClima = 1.10;
        }

        var ajusteFisiologico = 0;
        if (estadoFisiologico === "gravidez") {
            ajusteFisiologico = 0.3; // 300 ml = 0.3 litros
        } else if (estadoFisiologico === "lactacao") {
            ajusteFisiologico = 0.7; // 700 ml = 0.7 litros
        }

        var consumoTotal = consumoBasico * fatorAtividade * fatorClima + ajusteFisiologico;

        document.getElementById("resultado").innerHTML = `
            <h3>Consumo Diário de Água: ${consumoTotal.toFixed(2)} litros/dia</h3>
        `;
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_consumo_agua_dr', 'calculator_consumo_agua');

function calculator_vo2_max() {
    echo calculator_template_start('Calculadora de VO2 Máx');
    ?>
    <form id="vo2Form">
        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required><br><br>

        <label for="sexo">Sexo:</label>
        <select id="sexo" name="sexo" required>
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select><br><br>

        <label for="peso">Peso Corporal (kg):</label>
        <input type="number" id="peso" name="peso" step="0.1" required><br><br>

        <label for="teste">Teste Realizado:</label>
        <select id="teste" name="teste" required>
			<option value="cooper">Escolha o método)</option>
            <option value="cooper">Teste de Cooper (corrida de 12 min)</option>
            <option value="rockport">Teste de Rockport (caminhada de 1 milha)</option>
            <option value="bruce">Teste de Bruce (esteira)</option>
            <option value="astrand">Teste de Astrand-Ryhming (ciclismo)</option>
        </select><br><br>

        <div id="resultadosTeste"></div>

        <button type="submit">Calcular</button>
    </form>
    
    <div id="resultado"></div>

    <script>
    document.getElementById("teste").addEventListener("change", function() {
        var testeSelecionado = this.value;
        var resultadosTesteDiv = document.getElementById("resultadosTeste");

        resultadosTesteDiv.innerHTML = "";

        if (testeSelecionado === "cooper") {
            resultadosTesteDiv.innerHTML = `
                <label for="distancia">Distância percorrida (metros):</label>
                <input type="number" id="distancia" name="distancia" required><br><br>
            `;
        } else if (testeSelecionado === "rockport") {
            resultadosTesteDiv.innerHTML = `
                <label for="tempo">Tempo (minutos):</label>
                <input type="number" id="tempo" name="tempo" step="0.1" required><br><br>
                <label for="frequencia">Frequência Cardíaca Final (bpm):</label>
                <input type="number" id="frequencia" name="frequencia" required><br><br>
            `;
        } else if (testeSelecionado === "bruce") {
            resultadosTesteDiv.innerHTML = `
                <label for="tempoBruce">Tempo total (minutos):</label>
                <input type="number" id="tempoBruce" name="tempoBruce" step="0.1" required><br><br>
            `;
        } else if (testeSelecionado === "astrand") {
            resultadosTesteDiv.innerHTML = `
                <label for="frequenciaAstrand">Frequência Cardíaca Final (bpm):</label>
                <input type="number" id="frequenciaAstrand" name="frequenciaAstrand" required><br><br>
                <label for="carga">Carga de Trabalho (W):</label>
                <input type="number" id="carga" name="carga" required><br><br>
            `;
        }
    });

    document.getElementById("vo2Form").addEventListener("submit", function(event) {
        event.preventDefault();

        // Coletar dados do formulário
        var idade = parseFloat(document.getElementById("idade").value);
        var sexo = document.getElementById("sexo").value;
        var peso = parseFloat(document.getElementById("peso").value);
        var teste = document.getElementById("teste").value;

        var vo2max = 0;

        // Cálculo do VO2 Máx com base no teste selecionado
        if (teste === "cooper") {
            var distancia = parseFloat(document.getElementById("distancia").value);
            vo2max = (distancia - 504.9) / 44.73;
        } else if (teste === "rockport") {
            var tempo = parseFloat(document.getElementById("tempo").value);
            var frequencia = parseFloat(document.getElementById("frequencia").value);
            var genero = (sexo === "masculino") ? 1 : 0;
            vo2max = 132.853 - (0.0769 * peso) - (0.3877 * idade) + (6.315 * genero) - (3.2649 * tempo) - (0.1565 * frequencia);
        } else if (teste === "bruce") {
            var tempoBruce = parseFloat(document.getElementById("tempoBruce").value);
            if (sexo === "masculino") {
                vo2max = 14.8 - (1.379 * tempoBruce) + (0.451 * Math.pow(tempoBruce, 2));
            } else {
                vo2max = 4.38 * tempoBruce - 3.9;
            }
        } else if (teste === "astrand") {
            var frequenciaAstrand = parseFloat(document.getElementById("frequenciaAstrand").value);
            var carga = parseFloat(document.getElementById("carga").value);
            // O cálculo real de Astrand depende de tabelas e gráficos, mas aqui apenas exibimos os valores de entrada como placeholders.
            vo2max = "VO2 Máx baseado em tabela de Astrand (usar gráficos)";
        }

        // Exibir o resultado
        document.getElementById("resultado").innerHTML = `
            <h3>VO2 Máx: ${vo2max.toFixed(2)} ml/kg/min</h3>
        `;
    });
    </script>
    <?php
    return calculator_template_end();
}

add_shortcode('calc_vo2_max_dr', 'calculator_vo2_max');

function calculator_fcm() {
    echo calculator_template_start('Calculadora de Frequência Cardíaca Máxima');
    ?>
    <form id="fcmForm">
        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required><br><br>

        <label for="sexo">Sexo:</label>
        <select id="sexo" name="sexo" required>
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select><br><br>

        <label for="formula">Fórmula:</label>
        <select id="formula" name="formula" required>
            <option value="classica">Fórmula Clássica (220 - Idade)</option>
            <option value="tanaka">Fórmula de Tanaka (208 - 0.7 × Idade)</option>
            <option value="gellish">Fórmula de Gellish (206.9 - 0.67 × Idade)</option>
            <option value="inbar">Fórmula de Inbar (considera o sexo)</option>
        </select><br><br>

        <button type="submit">Calcular</button>
    </form>
    
    <div id="resultado"></div>

    <script>
    document.getElementById("fcmForm").addEventListener("submit", function(event) {
        event.preventDefault();

        var idade = parseFloat(document.getElementById("idade").value);
        var sexo = document.getElementById("sexo").value;
        var formula = document.getElementById("formula").value;

        var fcm = 0;

        if (formula === "classica") {
            fcm = 220 - idade;
        } else if (formula === "tanaka") {
            fcm = 208 - (0.7 * idade);
        } else if (formula === "gellish") {
            fcm = 206.9 - (0.67 * idade);
        } else if (formula === "inbar") {
            if (sexo === "masculino") {
                fcm = 205.8 - (0.685 * idade);
            } else {
                fcm = 206 - (0.88 * idade);
            }
        }

        var zonaAquecimento = [0.50 * fcm, 0.60 * fcm];
        var zonaAerobicaModerada = [0.60 * fcm, 0.70 * fcm];
        var zonaControlePeso = [0.70 * fcm, 0.80 * fcm];
        var zonaAnaerobica = [0.80 * fcm, 0.90 * fcm];
        var zonaEsforcoMaximo = [0.90 * fcm, fcm];

        document.getElementById("resultado").innerHTML = `
            <h3>Frequência Cardíaca Máxima: ${fcm.toFixed(2)} bpm</h3>
            <h4>Zonas de Treinamento:</h4>
            <p>Zona de Aquecimento (50% - 60%): ${zonaAquecimento[0].toFixed(2)} bpm a ${zonaAquecimento[1].toFixed(2)} bpm</p>
            <p>Zona Aeróbica Moderada (60% - 70%): ${zonaAerobicaModerada[0].toFixed(2)} bpm a ${zonaAerobicaModerada[1].toFixed(2)} bpm</p>
            <p>Zona de Controle de Peso (70% - 80%): ${zonaControlePeso[0].toFixed(2)} bpm a ${zonaControlePeso[1].toFixed(2)} bpm</p>
            <p>Zona Anaeróbica (80% - 90%): ${zonaAnaerobica[0].toFixed(2)} bpm a ${zonaAnaerobica[1].toFixed(2)} bpm</p>
            <p>Zona de Esforço Máximo (90% - 100%): ${zonaEsforcoMaximo[0].toFixed(2)} bpm a ${zonaEsforcoMaximo[1].toFixed(2)} bpm</p>
        `;
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_freq_cardiaca_maxima_dr', 'calculator_fcm');

function calculator_macronutrientes() {
    echo calculator_template_start('Calculadora de Macronutrientes');
    ?>
    <form id="macroForm">
        <label for="peso">Peso (kg):</label>
        <input type="number" id="peso" name="peso" required><br><br>

        <label for="altura">Altura (cm):</label>
        <input type="number" id="altura" name="altura" required><br><br>

        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required><br><br>

        <label for="sexo">Sexo:</label>
        <select id="sexo" name="sexo" required>
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select><br><br>

        <label for="atividade">Nível de Atividade Física:</label>
        <select id="atividade" name="atividade" required>
            <option value="sedentario">Sedentário</option>
            <option value="leve">Atividade Leve</option>
            <option value="moderada">Atividade Moderada</option>
            <option value="intensa">Atividade Intensa</option>
            <option value="atleta">Atleta</option>
        </select><br><br>

        <label for="objetivo">Objetivo:</label>
        <select id="objetivo" name="objetivo" required>
            <option value="perder_peso">Perder Peso</option>
            <option value="manter_peso">Manter Peso</option>
            <option value="ganhar_massa">Ganhar Massa Muscular</option>
        </select><br><br>

        <label for="tmb">Taxa Metabólica Basal (opcional, em kcal/dia):</label>
        <input type="number" id="tmb" name="tmb"><br><br>

        <button type="submit">Calcular</button>
    </form>
    
    <div id="resultado"></div>

    <script>
    document.getElementById("macroForm").addEventListener("submit", function(event) {
        event.preventDefault();

        var peso = parseFloat(document.getElementById("peso").value);
        var altura = parseFloat(document.getElementById("altura").value);
        var idade = parseFloat(document.getElementById("idade").value);
        var sexo = document.getElementById("sexo").value;
        var atividade = document.getElementById("atividade").value;
        var objetivo = document.getElementById("objetivo").value;
        var tmbInput = parseFloat(document.getElementById("tmb").value);

        var tmb = tmbInput || 0;

        if (!tmbInput) {
            if (sexo === "masculino") {
                tmb = (10 * peso) + (6.25 * altura) - (5 * idade) + 5;
            } else {
                tmb = (10 * peso) + (6.25 * altura) - (5 * idade) - 161;
            }
        }

        var fatorAtividade = {
            "sedentario": 1.2,
            "leve": 1.375,
            "moderada": 1.55,
            "intensa": 1.725,
            "atleta": 1.9
        };

        var tdee = tmb * fatorAtividade[atividade];

        var ajusteCalorias = 0;
        if (objetivo === "perder_peso") {
            ajusteCalorias = tdee * 0.85; // Reduz 15% para perda de peso
        } else if (objetivo === "manter_peso") {
            ajusteCalorias = tdee; // Manter o TDEE para manter o peso
        } else if (objetivo === "ganhar_massa") {
            ajusteCalorias = tdee * 1.10; // Aumenta 10% para ganhar massa muscular
        }

        var proporcaoMacronutrientes = {
            "perder_peso": { "proteinas": 0.30, "carboidratos": 0.40, "gorduras": 0.30 },
            "manter_peso": { "proteinas": 0.25, "carboidratos": 0.50, "gorduras": 0.25 },
            "ganhar_massa": { "proteinas": 0.35, "carboidratos": 0.45, "gorduras": 0.20 }
        };

        var macros = proporcaoMacronutrientes[objetivo];

        var caloriasProteinas = ajusteCalorias * macros.proteinas;
        var caloriasCarboidratos = ajusteCalorias * macros.carboidratos;
        var caloriasGorduras = ajusteCalorias * macros.gorduras;

        var gramasProteinas = caloriasProteinas / 4;
        var gramasCarboidratos = caloriasCarboidratos / 4;
        var gramasGorduras = caloriasGorduras / 9;

        document.getElementById("resultado").innerHTML = `
            <h3>Resultados:</h3>
            <p><strong>Taxa Metabólica Basal (TMB):</strong> ${tmb.toFixed(2)} kcal/dia</p>
            <p><strong>Necessidade Calórica Total (TDEE):</strong> ${tdee.toFixed(2)} kcal/dia</p>
            <p><strong>Calorias Ajustadas para o Objetivo:</strong> ${ajusteCalorias.toFixed(2)} kcal/dia</p>
            <h4>Distribuição de Macronutrientes:</h4>
            <p><strong>Proteínas:</strong> ${gramasProteinas.toFixed(2)} g/dia (${(macros.proteinas * 100).toFixed(0)}% das calorias)</p>
            <p><strong>Carboidratos:</strong> ${gramasCarboidratos.toFixed(2)} g/dia (${(macros.carboidratos * 100).toFixed(0)}% das calorias)</p>
            <p><strong>Gorduras:</strong> ${gramasGorduras.toFixed(2)} g/dia (${(macros.gorduras * 100).toFixed(0)}% das calorias)</p>
        `;
    });
    </script>
    <?php
    return calculator_template_end();
}

add_shortcode('calc_macronutrientes_dr', 'calculator_macronutrientes');

function calculator_percentual_gordura_corporal() {
    echo calculator_template_start('Calculadora de Percentual de Gordura Corporal');
    ?>
    <form id="gorduraForm">
        <label for="peso">Peso (kg):</label>
        <input type="number" id="peso" name="peso" required><br><br>

        <label for="altura">Altura (cm):</label>
        <input type="number" id="altura" name="altura" required><br><br>

        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required><br><br>

        <label for="sexo">Sexo:</label>
        <select id="sexo" name="sexo" required>
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select><br><br>

        <h4>Medidas Corporais:</h4>
        <label for="pescoco">Circunferência do Pescoço (cm):</label>
        <input type="number" id="pescoco" name="pescoco" required><br><br>

        <label for="cintura">Circunferência da Cintura (cm):</label>
        <input type="number" id="cintura" name="cintura" required><br><br>

        <div id="quadrilField" style="display: none;">
            <label for="quadril">Circunferência do Quadril (cm):</label>
            <input type="number" id="quadril" name="quadril"><br><br>
        </div>

        <label for="metodo">Método de Cálculo:</label>
        <select id="metodo" name="metodo" required>
            <option value="marinha">Fórmula da Marinha dos EUA</option>
            <!-- Outros métodos podem ser adicionados futuramente -->
        </select><br><br>

        <button type="submit">Calcular</button>
    </form>

    <div id="resultado"></div>

    <script>
    document.getElementById("sexo").addEventListener("change", function() {
        var sexo = document.getElementById("sexo").value;
        if (sexo === "feminino") {
            document.getElementById("quadrilField").style.display = "block";
        } else {
            document.getElementById("quadrilField").style.display = "none";
        }
    });

    document.getElementById("gorduraForm").addEventListener("submit", function(event) {
        event.preventDefault();

        var peso = parseFloat(document.getElementById("peso").value);
        var altura = parseFloat(document.getElementById("altura").value);
        var idade = parseFloat(document.getElementById("idade").value);
        var sexo = document.getElementById("sexo").value;
        var pescoco = parseFloat(document.getElementById("pescoco").value);
        var cintura = parseFloat(document.getElementById("cintura").value);
        var quadril = parseFloat(document.getElementById("quadril").value);
        var metodo = document.getElementById("metodo").value;

        var percentualGordura = 0;

        if (metodo === "marinha") {
            if (sexo === "masculino") {
                percentualGordura = 86.010 * Math.log10(cintura - pescoco) - 70.041 * Math.log10(altura) + 36.76;
            } else {
                percentualGordura = 163.205 * Math.log10(cintura + quadril - pescoco) - 97.684 * Math.log10(altura) - 78.387;
            }
        }

        var classificacao = "";
        if (sexo === "masculino") {
            if (percentualGordura < 14) {
                classificacao = "Atleta";
            } else if (percentualGordura < 18) {
                classificacao = "Bom";
            } else if (percentualGordura < 25) {
                classificacao = "Médio";
            } else {
                classificacao = "Acima da Média";
            }
        } else {
            if (percentualGordura < 21) {
                classificacao = "Atleta";
            } else if (percentualGordura < 25) {
                classificacao = "Bom";
            } else if (percentualGordura < 32) {
                classificacao = "Médio";
            } else {
                classificacao = "Acima da Média";
            }
        }

        document.getElementById("resultado").innerHTML = `
            <h3>Resultado:</h3>
            <p><strong>Percentual de Gordura Corporal:</strong> ${percentualGordura.toFixed(2)}%</p>
            <p><strong>Classificação:</strong> ${classificacao}</p>
        `;
    });
    </script>
    <?php
    return calculator_template_end();
}

add_shortcode('calc_percentual_gordura_dr', 'calculator_percentual_gordura_corporal');


function calculator_imc() {
    echo calculator_template_start('Calculadora de IMC');
    ?>
    <form id="imcForm">
        <label for="peso">Peso (kg):</label>
        <input type="number" id="peso" name="peso" required><br><br>

        <label for="altura">Altura (cm):</label>
        <input type="number" id="altura" name="altura" required><br><br>

        <label for="idade">Idade (opcional):</label>
        <input type="number" id="idade" name="idade"><br><br>

        <label for="sexo">Sexo (opcional):</label>
        <select id="sexo" name="sexo">
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select><br><br>

        <button type="submit">Calcular</button>
    </form>

    <div id="resultado"></div>

    <script>
    document.getElementById("imcForm").addEventListener("submit", function(event) {
        event.preventDefault();

        var peso = parseFloat(document.getElementById("peso").value);
        var altura = parseFloat(document.getElementById("altura").value);

        var alturaMetros = altura / 100;

        var imc = peso / (alturaMetros * alturaMetros);

        var classificacao = "";
        if (imc < 18.5) {
            classificacao = "Abaixo do Peso";
        } else if (imc >= 18.5 && imc <= 24.9) {
            classificacao = "Peso Normal";
        } else if (imc >= 25.0 && imc <= 29.9) {
            classificacao = "Sobrepeso";
        } else if (imc >= 30.0 && imc <= 34.9) {
            classificacao = "Obesidade Grau I";
        } else if (imc >= 35.0 && imc <= 39.9) {
            classificacao = "Obesidade Grau II";
        } else {
            classificacao = "Obesidade Grau III (Obesidade Mórbida)";
        }

        document.getElementById("resultado").innerHTML = `
            <h3>Resultado:</h3>
            <p><strong>IMC:</strong> ${imc.toFixed(2)}</p>
            <p><strong>Classificação:</strong> ${classificacao}</p>
        `;
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_imc_dr', 'calculator_imc');

function adicionar_frase_calculadora_no_final($content) {
    $shortcodes = array(
        'calc_vo2_max_dr', 
        'calc_reserva_vo2_dr', 
        'calc_macronutrientes_dr', 
        'calc_volume_treino_dr', 
        'calc_forca_maxima_dr', 
        'calc_consumo_agua_dr', 
        'calc_freq_cardiaca_maxima_dr', 
        'calc_imc_dr', 
        'calc_percentual_gordura_dr', 
        'calc_metas_peso_dr'
    );
    
    foreach ($shortcodes as $shortcode) {
        if (has_shortcode($content, $shortcode)) {
            // Frase a ser adicionada no final com o link
            $frase = '<p>Esta página usa uma calculadora desenvolvida por <a href="https://ambr.com.br" target="_blank">AMBR</a>.</p>';
            // Adiciona a frase ao final do conteúdo
            return $content . $frase;
        }
    }

    return $content;
}
add_filter('the_content', 'adicionar_frase_calculadora_no_final');
